Overview — toba 0.1.0 documentation

# Overview

docs |
tests |
package |

Timeliness Ordered Byzantine Agreement

- Free software: Apache2 license

## Installation

    pip install toba

## Documentation

https://toba.readthedocs.io/

## Development

To run the all tests run:

    tox

Note, to combine the coverage data from all the tox environments run:

Windows |
    set PYTEST_ADDOPTS=--cov-append
    tox
Other |
    PYTEST_ADDOPTS=--cov-append tox